#!/usr/bin/env python3
# fileops.py


import os

def readFile(path):
    if os.path.exists(path):
        return [{"file": "contents"}]
    else:
        print("File does not exist")
        return ''



def main():
    pass

if __name__ == '__main__':
    main()




import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="machette-lc-py-dotHTM",
    version="0.0.1",
    author="Mike Cramer",
    author_email="dothtm@icloud.com",
    description="A collection of hacks and functions that I use regularly.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/pypa/sampleproject",
    # project_urls={
    #     "Bug Tracker": "https://github.com/pypa/sampleproject/issues",
    # },
    # classifiers=[
    #     "Programming Language :: Python :: 3",
    #     "License :: OSI Approved :: MIT License",
    #     "Operating System :: OS Independent",
    # ],
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.6",
)
